pub struct CourseCreditRegistrationModuleConfigs {
pub modules: Vec<CourseModuleCreditRegistrationConfig>,
pub realisations: Vec<CourseModuleSuotarRealisation>,
}Expand description
Every module of the course with its Suotar configuration, for the module editor.
Fields
modules: Vec<CourseModuleCreditRegistrationConfig>realisations: Vec<CourseModuleSuotarRealisation>Every live realisation of every module of the course, to be grouped by course_module_id.