pub struct CourseCreditRegistrationModuleSummary {
pub course_module_id: Uuid,
pub course_module_name: Option<String>,
pub enabled: bool,
pub paused: bool,
pub counts_by_state: Vec<CreditRegistrationStateCount>,
pub success_count: i64,
pub failed_permanent_count: i64,
pub needs_admin_attention_count: i64,
}Fields
course_module_id: Uuidcourse_module_name: Option<String>enabled: boolpaused: boolcounts_by_state: Vec<CreditRegistrationStateCount>success_count: i64registered, duplicate and not_improved: the credit exists in Sisu.
failed_permanent_count: i64failed_permanent only: a retrying row is still working and misregistered is not terminal.
needs_admin_attention_count: i64Trait Implementations
Sourceimpl Clone for CourseCreditRegistrationModuleSummary
impl Clone for CourseCreditRegistrationModuleSummary
Sourcefn clone(&self) -> CourseCreditRegistrationModuleSummary
fn clone(&self) -> CourseCreditRegistrationModuleSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CourseCreditRegistrationModuleSummary
impl ComposeSchema for CourseCreditRegistrationModuleSummary
Sourceimpl<'de> Deserialize<'de> for CourseCreditRegistrationModuleSummary
impl<'de> Deserialize<'de> for CourseCreditRegistrationModuleSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CourseCreditRegistrationModuleSummary
impl PartialEq for CourseCreditRegistrationModuleSummary
Sourcefn eq(&self, other: &CourseCreditRegistrationModuleSummary) -> bool
fn eq(&self, other: &CourseCreditRegistrationModuleSummary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ToSchema for CourseCreditRegistrationModuleSummary
impl ToSchema for CourseCreditRegistrationModuleSummary
impl StructuralPartialEq for CourseCreditRegistrationModuleSummary